pub struct MathPrimitiveOptions {Show 38 fields
pub bounded: bool,
pub mode: Option<String>,
pub before_digest: Vec<BeforeDigestClosure>,
pub after_digest: Vec<DigestionClosure>,
pub before_construct: Vec<ConstructionClosure>,
pub after_construct: Vec<ConstructionClosure>,
pub is_prefix: bool,
pub scope: Option<Scope>,
pub font: Option<FontDirective>,
pub require_math: bool,
pub forbid_math: bool,
pub locked: bool,
pub alias: Option<String>,
pub decl_id: Option<String>,
pub replace: Option<String>,
pub protected: bool,
pub robust: bool,
pub name: Option<String>,
pub meaning: Option<String>,
pub omcd: Option<String>,
pub reversion: Option<Reversion>,
pub sizer: Option<SizingClosure>,
pub role: Option<String>,
pub operator_role: Option<String>,
pub reorder: bool,
pub dual: bool,
pub mathstyle: Option<String>,
pub dynamic_mathstyle: bool,
pub scriptpos: Option<String>,
pub dynamic_scriptpos: bool,
pub operator_scriptpos: Option<usize>,
pub stretchy: Option<bool>,
pub operator_stretchy: Option<bool>,
pub nogroup: bool,
pub hide_content_reversion: bool,
pub revert_as: Option<Cow<'static, str>>,
pub lpadding: Option<usize>,
pub rpadding: Option<usize>,
}Fields
bounded: boolmode: Option<String>before_digest: Vec<BeforeDigestClosure>after_digest: Vec<DigestionClosure>before_construct: Vec<ConstructionClosure>after_construct: Vec<ConstructionClosure>is_prefix: boolscope: Option<Scope>font: Option<FontDirective>require_math: boolforbid_math: boollocked: boolalias: Option<String>decl_id: Option<String>replace: Option<String>protected: boolrobust: boolname: Option<String>meaning: Option<String>omcd: Option<String>reversion: Option<Reversion>sizer: Option<SizingClosure>role: Option<String>operator_role: Option<String>reorder: booldual: boolmathstyle: Option<String>dynamic_mathstyle: boolDynamic mathstyle: compute “display”/“text” based on current font mathstyle at invocation time Perl: mathstyle => &doVariablesizeOp
scriptpos: Option<String>dynamic_scriptpos: boolDynamic scriptpos: compute “mid”/“post” based on current font mathstyle at invocation time Perl: scriptpos => &doScriptpos
operator_scriptpos: Option<usize>stretchy: Option<bool>operator_stretchy: Option<bool>nogroup: boolhide_content_reversion: boolrevert_as: Option<Cow<'static, str>>lpadding: Option<usize>rpadding: Option<usize>Implementations
Sourceimpl MathPrimitiveOptions
impl MathPrimitiveOptions
pub fn to_hash_stored(&self) -> HashMap<Stored>
Sourcepub fn to_hash_stored_with_overrides(
&self,
mode_override: Option<&'static str>,
mathstyle_override: Option<&'static str>,
scriptpos_override: Option<&'static str>,
) -> HashMap<Stored>
pub fn to_hash_stored_with_overrides( &self, mode_override: Option<&'static str>, mathstyle_override: Option<&'static str>, scriptpos_override: Option<&'static str>, ) -> HashMap<Stored>
Like to_hash_stored but applies per-invocation overrides without
cloning the whole options. Used in DefMath closures (hot path —
one call per math token invocation).
Sourcepub fn has_complex_option(&self) -> bool
pub fn has_complex_option(&self) -> bool
Checks if complex options are present,
suggestive of using a Constructor instead of a Primitive